==> piwigo-11.5.0.zip: piwigo/language/eu_ES/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo saia daiteke konfigurazioa PHP 5.2 bertsiora aldatzen  .htacces fitxategi bat sortuz edo aldatuz.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Zure ostalariaren laguntza-zerbitzura jo beharko zenuke eta PHP 5.2ra aldatzeko proposatzen diren pausuak jarraitu.';
$lang['please enter your password again'] = 'idatzi pasahitza eta saiatu berriro';
$lang['localhost or other, supplied by your host provider'] = 'localhost edo besterik, zure ostalariak emana';
$lang['also given by your host provider'] = 'zure ostalariak emana baita ere';
$lang['enter a login for webmaster'] = 'idatzi web-arduradunaren erabiltzaile-izena';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'datu-basearen taula-izenek eramango duten aurrizkia (taulak kudeatzeko lagungarria)';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Konfigurazio-fitxategia deskargatu eta zure instalazioaren local/config direktorioan kargatu dezakezu.';
$lang['Welcome to your new installation of Piwigo!'] = 'Ongietorri zure Piwigo instalazio berrira';
$lang['Welcome to my photo gallery'] = 'Ongietorri nire argazki-galeriara';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Bisitariek helbide elektroniko hau erabiltzeko aukera izango dute guneko administrariarekin kontaktatzeko';
$lang['User'] = 'Erabiltzailea';
$lang['Try to configure PHP 5'] = 'Saiatu PHP 5.2ra konfiguratzen';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigok ezin izan du PHP 5.2ra konfiguratu';
$lang['Start Install'] = 'Hasi instalazioa';
$lang['Sorry!'] = 'Barkatu!';
$lang['Password ']['confirm'] = 'Pasahitza[baieztatu]';
$lang['PHP 5 is required'] = 'PHP 5.2 behar da';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Kontuan izan zure konfigurazioa aldatu eta Piwigo berrabiarazteko aukera duzula.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Laguntzarik behar? Galdetu <a href="%s">Piwigo foroan</a>.';
$lang['user login given by your host provider'] = 'zure ostalariak emandako erabiltzaile-izena';
$lang['user password given by your host provider'] = 'zure ostalariak emandako erabiltzaile-pasahitza';
$lang['verification'] = 'egiaztapena';
$lang['webmaster login can\'t contain characters \' or "'] = 'web-arduradunaren izenak ezin ditu izan \' edo " karaktererik';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Ordezko konponbide modura kopiatu goiko koadroko testua eta itsatsi "local/config/database.inc.php" fitxategian (Oharra: database.inc.php fitxategiak testu-eremuan dagoena baino ez du eduki behar, ez lerro-saltorik ez hutsunerik)';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantendu ezkutuan, administrazio-panelera sartzen gaitzen dizu';
$lang['Just another Piwigo gallery'] = 'Beste Piwigo galeria bat';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bisitariei erakutsiko zaie. Beharrezkoa da webguneen administraziorako';
$lang['It appears your webhost is currently running PHP %s.'] = 'Antza denez, zure web ostalariak PHP %s exekutatzen ari da. ';
$lang['Installation'] = 'Instalazioa';
$lang['Host'] = 'Ostalaria';
$lang['Hope to see you back soon.'] = 'Ea laster ikusten dugun elkar berriro.';
$lang['Download the config file'] = 'Deskargatu konfigurazio-fitxategia';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Huts egin du local/config/database.inc.php konfigurazio-fitxategiaren sortzeak.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Kontsultatu gure foroak edozein zalantzatarako: %s';
$lang['Default gallery language'] = 'Galeriaren lehenetsitako hizkuntza';
$lang['Database table prefix'] = 'Datu-basearen taulen aurrizkia';
$lang['Database name'] = 'Datu-basearen izena';
$lang['Database configuration'] = 'Datu-basearen konfigurazioa';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Ondo konektatu da zerbitzariarekin baina ezin izan da datu-basearekin konektatu';
$lang['Congratulations, Piwigo installation is completed'] = 'Zorionak, Piwigo instalazioa osorik burutu da';
$lang['Can\'t connect to server'] = 'Ezin izan da zerbitzariarekin konektatu';
$lang['Basic configuration'] = 'Oinarrizko konfigurazioa';
$lang['Admin configuration'] = 'Administrazio konfigurazioa';

==> piwigo-15.7.0.zip: piwigo/language/eu_ES/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo saia daiteke konfigurazioa PHP 5.2 bertsiora aldatzen  .htacces fitxategi bat sortuz edo aldatuz.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Zure ostalariaren laguntza-zerbitzura jo beharko zenuke eta PHP 5.2ra aldatzeko proposatzen diren pausuak jarraitu.';
$lang['please enter your password again'] = 'idatzi pasahitza eta saiatu berriro';
$lang['localhost or other, supplied by your host provider'] = 'localhost edo besterik, zure ostalariak emana';
$lang['also given by your host provider'] = 'zure ostalariak emana baita ere';
$lang['enter a login for webmaster'] = 'idatzi web-arduradunaren erabiltzaile-izena';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'datu-basearen taula-izenek eramango duten aurrizkia (taulak kudeatzeko lagungarria)';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Konfigurazio-fitxategia deskargatu eta zure instalazioaren local/config direktorioan kargatu dezakezu.';
$lang['Welcome to your new installation of Piwigo!'] = 'Ongietorri zure Piwigo instalazio berrira';
$lang['Welcome to my photo gallery'] = 'Ongietorri nire argazki-galeriara';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Bisitariek helbide elektroniko hau erabiltzeko aukera izango dute guneko administrariarekin kontaktatzeko';
$lang['User'] = 'Erabiltzailea';
$lang['Try to configure PHP 5'] = 'Saiatu PHP 5.2ra konfiguratzen';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigok ezin izan du PHP 5.2ra konfiguratu';
$lang['Start Install'] = 'Hasi instalazioa';
$lang['Sorry!'] = 'Barkatu!';
$lang['Password ']['confirm'] = 'Pasahitza[baieztatu]';
$lang['PHP 5 is required'] = 'PHP 5.2 behar da';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Kontuan izan zure konfigurazioa aldatu eta Piwigo berrabiarazteko aukera duzula.';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Laguntzarik behar? Galdetu <a href="%s">Piwigo foroan</a>.';
$lang['user login given by your host provider'] = 'zure ostalariak emandako erabiltzaile-izena';
$lang['user password given by your host provider'] = 'zure ostalariak emandako erabiltzaile-pasahitza';
$lang['verification'] = 'egiaztapena';
$lang['webmaster login can\'t contain characters \' or "'] = 'web-arduradunaren izenak ezin ditu izan \' edo " karaktererik';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Ordezko konponbide modura kopiatu goiko koadroko testua eta itsatsi "local/config/database.inc.php" fitxategian (Oharra: database.inc.php fitxategiak testu-eremuan dagoena baino ez du eduki behar, ez lerro-saltorik ez hutsunerik)';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantendu ezkutuan, administrazio-panelera sartzen gaitzen dizu';
$lang['Just another Piwigo gallery'] = 'Beste Piwigo galeria bat';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bisitariei erakutsiko zaie. Beharrezkoa da webguneen administraziorako';
$lang['It appears your webhost is currently running PHP %s.'] = 'Antza denez, zure web ostalariak PHP %s exekutatzen ari da. ';
$lang['Installation'] = 'Instalazioa';
$lang['Host'] = 'Ostalaria';
$lang['Hope to see you back soon.'] = 'Ea laster ikusten dugun elkar berriro.';
$lang['Download the config file'] = 'Deskargatu konfigurazio-fitxategia';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Huts egin du local/config/database.inc.php konfigurazio-fitxategiaren sortzeak.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Kontsultatu gure foroak edozein zalantzatarako: %s';
$lang['Default gallery language'] = 'Galeriaren lehenetsitako hizkuntza';
$lang['Database table prefix'] = 'Datu-basearen taulen aurrizkia';
$lang['Database name'] = 'Datu-basearen izena';
$lang['Database configuration'] = 'Datu-basearen konfigurazioa';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Ondo konektatu da zerbitzariarekin baina ezin izan da datu-basearekin konektatu';
$lang['Congratulations, Piwigo installation is completed'] = 'Zorionak, Piwigo instalazioa osorik burutu da';
$lang['Can\'t connect to server'] = 'Ezin izan da zerbitzariarekin konektatu';
$lang['Basic configuration'] = 'Oinarrizko konfigurazioa';
$lang['Admin configuration'] = 'Administrazio konfigurazioa';
$lang['PHP version %s required (you are running on PHP %s)'] = 'PHP %s bertsioa behar da (PHP %s bertsioa erabiltzen zaude';
